==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/vi-VN/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Phụ kiện đã cấp phát thành công',
    'Accessory_Checkout_Notification' => 'Phụ kiện đã cấp phát thành công',
    'Asset_Checkin_Notification' => 'Tài sản đã cấp phát thành công',
    'Asset_Checkout_Notification' => 'Tài sản đã cấp phát thành công',
    'Confirm_Accessory_Checkin' => 'Xác nhận cấp phát Phụ kiện',
    'Confirm_Asset_Checkin' => 'Xác nhận cấp phát tài sản',
    'Confirm_accessory_delivery' => 'Xác nhận bàn giao phụ kiện',
    'Confirm_asset_delivery' => 'Xác nhận bàn giao tài sản',
    'Confirm_consumable_delivery' => 'Xác nhận bàn giao tài sản tiêu hao',
    'Confirm_license_delivery' => 'Xác nhận chuyển giao giấy phép',
    'Consumable_checkout_notification' => 'Vật tư đã cấp phát thành công',
    'Days' => 'Ngày',
    'Expected_Checkin_Date' => 'Một tài sản đã thu hồi về cho bạn vì đã hoàn lại vào ngày :date',
    'Expected_Checkin_Notification' => 'Nhắn nhở: hạn chót cấp phát cho :name gần đến',
    'Expected_Checkin_Report' => 'Báo cáo mong muốn cấp phát tài sản',
    'Expiring_Assets_Report' => 'Báo cáo tài sản đang hết hạn.',
    'Expiring_Licenses_Report' => 'Giấy phép Giấy phép hết hạn.',
    'Item_Request_Canceled' => 'Yêu cầu Mặt hàng bị Hủy',
    'Item_Requested' => 'Yêu cầu',
    'License_Checkin_Notification' => 'Giấy phép đã cấp phát thành công',
    'License_Checkout_Notification' => 'Giấy phép đã cấp phát thành công',
    'Low_Inventory_Report' => 'Báo cáo tồn kho thấp',
    'a_user_canceled' => 'Người dùng đã hủy bỏ một khoản mục yêu cầu trên trang web',
    'a_user_requested' => 'Người dùng đã yêu cầu một mục trên trang web',
    'acceptance_asset_accepted' => 'Người dùng đã chấp nhận',
    'acceptance_asset_declined' => 'Người dùng từ chối',
    'accessory_name' => 'Tên Phụ Kiện:',
    'additional_notes' => 'Ghi chú bổ sung:',
    'admin_has_created' => 'Người quản trị đã tạo ra một tài khoản cho bạn trên trang web :web.',
    'asset' => 'Tài sản:',
    'asset_name' => 'Tên tài sản:',
    'asset_requested' => 'Tài sản được yêu cầu',
    'asset_tag' => 'Thẻ tài sản',
    'assets_warrantee_alert' => 'Tài sản có bảo hành sắp hết hạn vào ngày mai: threshold days. | Tài sản có bảo hành sắp hết hạn trong ngày mai: threshold days.',
    'assigned_to' => 'Cấp phát cho',
    'best_regards' => 'Trân trọng,',
    'canceled' => 'Đã hủy bỏ:',
    'checkin_date' => 'Ngày cấp phát:',
    'checkout_date' => 'Ngày thu hồi:',
    'checkedout_from' => 'Biểu mẫu cấp phát',
    'checkedin_from'  => 'Biểu mẫu đã kiểm tra',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Vui lòng click chuột lên liên kết ở bên dưới để xác nhận Anh/Chị đã nhận phụ kiện.',
    'click_on_the_link_asset' => 'Vui lòng click chuột lên liên kết bên dưới để xác nhận Anh/Chị đã nhận tài sản.',
    'click_to_confirm' => 'Vui lòng click chuột lên liên kết bên dưới để xác nhận tài khoản :web của Anh/Chị:',
    'current_QTY' => 'QTY hiện tại',
    'days' => 'Ngày',
    'expecting_checkin_date' => 'Dự kiến ​​ngày Checkin:',
    'expires' => 'Hết hạn',
    'hello' => 'xin chào',
    'hi' => 'Chào',
    'i_have_read' => 'Tôi đã đọc và đồng ý với các điều khoản sử dụng và đã nhận được mục này.',
    'inventory_report' => 'Báo cáo kho',
    'item' => 'Mục:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Có: giấy phép bản quyền sắp hết hạn trong ngày mai:threshold days. | Có nhiều: giấy phép bản quyên sắp hết hạn trong lần tiếp theo: threshold days.',
    'link_to_update_password' => 'Vui lòng nhấp vào liên kết sau để cập nhật: mật khẩu web:',
    'login' => 'Đăng nhập:',
    'login_first_admin' => 'Đăng nhập vào hệ thống Snipe-IT mới bằng các thông tin dưới đây:',
    'low_inventory_alert' => 'Có: mặt hàng tồn dưới mức tối thiểu hoặc sẽ sớm ở mức thấp. | Có nhiều: mặt hàng tồn dưới mức tồn kho tối thiểu hoặc sẽ sớm ở mức thấp.',
    'min_QTY' => 'Min QTY',
    'name' => 'Tên',
    'new_item_checked' => 'Một mục mới đã được kiểm tra dưới tên của bạn, chi tiết dưới đây.',
    'notes' => 'Ghi chú',
    'password' => 'Mật khẩu:',
    'password_reset' => 'Đặt lại mật khẩu',
    'read_the_terms' => 'Vui lòng đọc các điều khoản sử dụng bên dưới.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Yêu cầu:',
    'reset_link' => 'Liên kết Đặt lại Mật khẩu của bạn',
    'reset_password' => 'Nhấn vào đây để đặt lại mật khẩu của bạn:',
    'rights_reserved' => 'Bản quyền được bảo hộ.',
    'serial' => 'Serial - Seri',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Nhà cung cấp',
    'tag' => 'Nhãn',
    'test_email' => 'Kiểm tra Email từ Snipe-IT',
    'test_mail_text' => 'Đây là một bài kiểm tra từ Hệ thống Quản lý Tài sản Snipe-IT. Nếu bạn nhận được điều này, mail đang làm việc :)',
    'the_following_item' => 'Mục dưới đây đã được kiểm tra:',
    'to_reset' => 'Để đặt lại mật khẩu web của bạn, hãy hoàn thành biểu mẫu này:',
    'type' => 'Kiểu',
    'upcoming-audits' => 'Hiện có :count tài sản sẽ được xem xét trong :threshold này nữa.',
    'user' => 'Người dùng',
    'username' => 'Tên đăng nhập',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Chào mừng: tên',
    'welcome_to' => 'Chào mừng đến với: web!',
    'your_assets' => 'Xen qua tài sản của bạn',
    'your_credentials' => 'Thông tin về Snipe-IT của bạn',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/vi-VN/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Phụ kiện đã cấp phát thành công',
    'Accessory_Checkout_Notification' => 'Phụ kiện đã cấp phát thành công',
    'Asset_Checkin_Notification' => 'Tài sản đã cấp phát thành công',
    'Asset_Checkout_Notification' => 'Tài sản đã cấp phát thành công',
    'Confirm_Accessory_Checkin' => 'Xác nhận cấp phát Phụ kiện',
    'Confirm_Asset_Checkin' => 'Xác nhận cấp phát tài sản',
    'Confirm_accessory_delivery' => 'Xác nhận bàn giao phụ kiện',
    'Confirm_asset_delivery' => 'Xác nhận bàn giao tài sản',
    'Confirm_consumable_delivery' => 'Xác nhận bàn giao tài sản tiêu hao',
    'Confirm_license_delivery' => 'Xác nhận chuyển giao giấy phép',
    'Consumable_checkout_notification' => 'Vật tư đã cấp phát thành công',
    'Days' => 'Ngày',
    'Expected_Checkin_Date' => 'Một tài sản đã thu hồi về cho bạn vì đã hoàn lại vào ngày :date',
    'Expected_Checkin_Notification' => 'Nhắn nhở: hạn chót cấp phát cho :name gần đến',
    'Expected_Checkin_Report' => 'Báo cáo mong muốn cấp phát tài sản',
    'Expiring_Assets_Report' => 'Báo cáo tài sản đang hết hạn.',
    'Expiring_Licenses_Report' => 'Giấy phép Giấy phép hết hạn.',
    'Item_Request_Canceled' => 'Yêu cầu Mặt hàng bị Hủy',
    'Item_Requested' => 'Yêu cầu',
    'License_Checkin_Notification' => 'Giấy phép đã cấp phát thành công',
    'License_Checkout_Notification' => 'Giấy phép đã cấp phát thành công',
    'Low_Inventory_Report' => 'Báo cáo tồn kho thấp',
    'a_user_canceled' => 'Người dùng đã hủy bỏ một khoản mục yêu cầu trên trang web',
    'a_user_requested' => 'Người dùng đã yêu cầu một mục trên trang web',
    'acceptance_asset_accepted' => 'Người dùng đã chấp nhận',
    'acceptance_asset_declined' => 'Người dùng từ chối',
    'accessory_name' => 'Tên Phụ Kiện',
    'additional_notes' => 'Ghi chú bổ sung',
    'admin_has_created' => 'Người quản trị đã tạo ra một tài khoản cho bạn trên trang web :web.',
    'asset' => 'Tài sản',
    'asset_name' => 'Tên tài sản',
    'asset_requested' => 'Tài sản được yêu cầu',
    'asset_tag' => 'Thẻ tài sản',
    'assets_warrantee_alert' => 'Tài sản có bảo hành sắp hết hạn vào ngày mai: threshold days. | Tài sản có bảo hành sắp hết hạn trong ngày mai: threshold days.',
    'assigned_to' => 'Cấp phát cho',
    'best_regards' => 'Trân trọng,',
    'canceled' => 'Canceled',
    'checkin_date' => 'Ngày Checkin',
    'checkout_date' => 'Ngày checkout',
    'checkedout_from' => 'Biểu mẫu cấp phát',
    'checkedin_from'  => 'Biểu mẫu đã kiểm tra',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'Vui lòng click chuột lên liên kết ở bên dưới để xác nhận Anh/Chị đã nhận phụ kiện.',
    'click_on_the_link_asset' => 'Vui lòng click chuột lên liên kết bên dưới để xác nhận Anh/Chị đã nhận tài sản.',
    'click_to_confirm' => 'Vui lòng click chuột lên liên kết bên dưới để xác nhận tài khoản :web của Anh/Chị:',
    'current_QTY' => 'QTY hiện tại',
    'days' => 'Ngày',
    'expecting_checkin_date' => 'Ngày mong muốn Checkin',
    'expires' => 'Hết hạn',
    'hello' => 'xin chào',
    'hi' => 'Chào',
    'i_have_read' => 'Tôi đã đọc và đồng ý với các điều khoản sử dụng và đã nhận được mục này.',
    'inventory_report' => 'Báo cáo kho',
    'item' => 'Mục',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Có: giấy phép bản quyền sắp hết hạn trong ngày mai:threshold days. | Có nhiều: giấy phép bản quyên sắp hết hạn trong lần tiếp theo: threshold days.',
    'link_to_update_password' => 'Vui lòng nhấp vào liên kết sau để cập nhật: mật khẩu web:',
    'login' => 'Đăng nhập:',
    'login_first_admin' => 'Đăng nhập vào hệ thống Snipe-IT mới bằng các thông tin dưới đây:',
    'low_inventory_alert' => 'Có: mặt hàng tồn dưới mức tối thiểu hoặc sẽ sớm ở mức thấp. | Có nhiều: mặt hàng tồn dưới mức tồn kho tối thiểu hoặc sẽ sớm ở mức thấp.',
    'min_QTY' => 'Min QTY',
    'name' => 'Tên',
    'new_item_checked' => 'Một mục mới đã được kiểm tra dưới tên của bạn, chi tiết dưới đây.',
    'notes' => 'Ghi chú',
    'password' => 'Mật khẩu',
    'password_reset' => 'Đặt lại mật khẩu',
    'read_the_terms' => 'Vui lòng đọc các điều khoản sử dụng bên dưới.',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'Đã yêu cầu',
    'reset_link' => 'Liên kết Đặt lại Mật khẩu của bạn',
    'reset_password' => 'Nhấn vào đây để đặt lại mật khẩu của bạn:',
    'rights_reserved' => 'Bản quyền được bảo hộ.',
    'serial' => 'Serial - Seri',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'Nhà cung cấp',
    'tag' => 'Nhãn',
    'test_email' => 'Kiểm tra Email từ Snipe-IT',
    'test_mail_text' => 'Đây là một bài kiểm tra từ Hệ thống Quản lý Tài sản Snipe-IT. Nếu bạn nhận được điều này, mail đang làm việc :)',
    'the_following_item' => 'Mục dưới đây đã được kiểm tra:',
    'to_reset' => 'Để đặt lại mật khẩu web của bạn, hãy hoàn thành biểu mẫu này:',
    'type' => 'Kiểu',
    'upcoming-audits' => 'Hiện có :count tài sản sẽ được xem xét trong :threshold này nữa.',
    'user' => 'Người dùng',
    'username' => 'Tên đăng nhập',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Chào mừng: tên',
    'welcome_to' => 'Chào mừng đến với: web!',
    'your_assets' => 'Xen qua tài sản của bạn',
    'your_credentials' => 'Thông tin về Snipe-IT của bạn',
    'mail_sent' => 'Mail sent successfully!',
];
